/**
 * Copyright (C) 2012 by Justin Windle
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
jQuery(document).ready(function(){
	
	function has3d() {
	    var el = document.createElement('p'), 
	        has3d,
	        transforms = {
	            'WebkitTransform':'-webkit-transform',
	            'OTransform':'-o-transform',
	            'MSTransform':'-ms-transform',
	            'MozTransform':'-moz-transform',
	            'Transform':'transform'
	        };
	
	    // Add it to the body to get the computed style.
	    document.body.insertBefore(el, null);
	
	    for (var t in transforms) {
	        if (el.style[t] !== undefined) {
	            el.style[t] = "translate3d(1px,1px,1px)";
	            has3d = window.getComputedStyle(el).getPropertyValue(transforms[t]);
	        }
	    }
	
	    document.body.removeChild(el);
	
	    return (has3d !== undefined && has3d.length > 0 && has3d !== "none");
	}
	
	if (has3d()) {
	
	jQuery('#listTitle span').text('+');
	jQuery('#listTitle').css('display', 'block');
	
(function($) {

    // Global initialisation flag
    var initialized = false;

    // For detecting browser prefix and capabilities
    var el = document.createElement( 'div' );
    var re = /^(Moz|(w|W)ebkit|O|ms)(?=[A-Z])/;

    // Establish vendor prefix and CSS 3D support
    var vendor = (function() { for ( var p in el.style ) if( re.test(p) ) return p.match(re)[0]; })() || '';
    var canRun = vendor + 'Perspective' in el.style;
    var prefix = '-' + vendor.toLowerCase() + '-';

    var jQuerythis, jQueryroot, jQuerybase, jQuerykids, jQuerynode, jQueryitem, jQueryover, jQueryback;
    var wait, anim, last;

    // Public API
    var api = {

        // Toggle open / closed
        toggle: function() {

            jQuerythis = jQuery( this );
            jQuerythis.makisu( jQuerythis.hasClass( 'open' ) ? 'close' : 'open' );
        },

        // Trigger the unfold animation
        open: function( speed, overlap, easing ) {

            // Cache DOM references
            jQuerythis = jQuery(this);
            jQueryroot = jQuerythis.find( '.root' );
            jQuerykids = jQuerythis.find( '.node' ).not( jQueryroot );

            // Establish values or fallbacks
            speed = utils.resolve( jQuerythis, 'speed', speed );
            easing = utils.resolve( jQuerythis, 'easing', easing );
            overlap = utils.resolve( jQuerythis, 'overlap', overlap );

            jQuerykids.each( function( index, el ) {

                // Establish settings for this iteration
                anim = 'unfold' + ( !index ? '-first' : '' );
                last = index === jQuerykids.length - 1;
                time = speed * ( 1 - overlap );
                wait = index * time;

                // Cache DOM references
                jQueryitem = jQuery( el );
                jQueryover = jQueryitem.find( '.over' );

                // Element animation
                jQueryitem.css(utils.prefix({
                    'transform': 'rotateX(180deg)',
                    'animation': anim + ' ' + speed + 's ' + easing + ' ' + wait + 's 1 normal forwards'
                }));

                // Shading animation happens when the next item starts
                if ( !last ) wait = ( index + 1 ) * time;

                // Shading animation
                jQueryover.css(utils.prefix({
                    'animation': 'unfold-over ' + (speed * 0.45) + 's ' + easing + ' ' + wait + 's 1 normal forwards'
                }));
            });

            // Add momentum to the container
            jQueryroot.css(utils.prefix({
                'animation': 'swing-out ' + ( jQuerykids.length * time * 1.4 ) + 's ease-in-out 0s 1 normal forwards'
            }));

            jQuerythis.addClass( 'open' );
        },

        // Trigger the fold animation
        close: function( speed, overlap, easing ) {

            // Cache DOM references
            jQuerythis = jQuery(this);
            jQueryroot = jQuerythis.find( '.root' );
            jQuerykids = jQuerythis.find( '.node' ).not( jQueryroot );

            // Establish values or fallbacks
            speed = utils.resolve( jQuerythis, 'speed', speed ) * 0.66;
            easing = utils.resolve( jQuerythis, 'easing', easing );
            overlap = utils.resolve( jQuerythis, 'overlap', overlap );

            jQuerykids.each( function( index, el ) {

                // Establish settings for this iteration
                anim = 'fold' + ( !index ? '-first' : '' );
                last = index === 0;
                time = speed * ( 1 - overlap );
                wait = ( jQuerykids.length - index - 1 ) * time;

                // Cache DOM references
                jQueryitem = jQuery( el );
                jQueryover = jQueryitem.find( '.over' );

                // Element animation
                jQueryitem.css(utils.prefix({
                    'transform': 'rotateX(0deg)',
                    'animation': anim + ' ' + speed + 's ' + easing + ' ' + wait + 's 1 normal forwards'
                }));

                // Adjust delay for shading
                if ( !last ) wait = ( ( jQuerykids.length - index - 2 ) * time ) + ( speed * 0.35 );

                // Shading animation
                jQueryover.css(utils.prefix({
                    'animation': 'fold-over ' + (speed * 0.45) + 's ' + easing + ' ' + wait + 's 1 normal forwards'
                }));
            });

            // Add momentum to the container
            jQueryroot.css(utils.prefix({
                'animation': 'swing-in ' + ( jQuerykids.length * time * 1.0 ) + 's ease-in-out 0s 1 normal forwards'
            }));

            jQuerythis.removeClass( 'open' );
        }
    };

    // Utils
    var utils = {

        // Resolves argument values to defaults
        resolve: function( jQueryel, key, val ) {
            return typeof val === 'undefined' ? jQueryel.data( key ) : val;
        },

        // Prefixes a hash of styles with the current vendor
        prefix: function( style ) {
            
            for ( var key in style ) {
                style[ prefix + key ] = style[ key ];
            }

            return style;
        },

        // Inserts rules into the document styles
        inject: function( rule ) {

            try {

                var style = document.createElement( 'style' );
                style.innerHTML = rule;
                document.getElementsByTagName( 'head' )[0].appendChild( style );

            } catch ( error ) {}
        }
    };

    // Element templates
    var markup = {
        node: '<span class="node"/>',
        back: '<span class="face back"/>',
        over: '<span class="face over"/>'
    };

    // Plugin definition
    jQuery.fn.makisu = function( options ) {

        // Notify if 3D isn't available
        if ( !canRun ) {

            var message = 'Failed to detect CSS 3D support';

            if( console && console.warn ) {
                
                // Print warning to the console
                console.warn( message );

                // Trigger errors on elements
                this.each( function() {
                    jQuery( this ).trigger( 'error', message );
                });
            }

            return;
        }

        // Fires only once
        if ( !initialized ) {

            initialized = true;

            // Unfold
            utils.inject( '@' + prefix + 'keyframes unfold        {' +

                '0%   {' + prefix + 'transform: rotateX(180deg);  }' +
                '50%  {' + prefix + 'transform: rotateX(-30deg);  }' +
                '100% {' + prefix + 'transform: rotateX(0deg);    }' +

                '}');

            // Unfold (first item)
            utils.inject( '@' + prefix + 'keyframes unfold-first  {' +

                '0%   {' + prefix + 'transform: rotateX(-90deg);  }' +
                '50%  {' + prefix + 'transform: rotateX(60deg);   }' +
                '100% {' + prefix + 'transform: rotateX(0deg);    }' +

                '}');

            // Fold
            utils.inject( '@' + prefix + 'keyframes fold          {' +

                '0%   {' + prefix + 'transform: rotateX(0deg);    }' +
                '100% {' + prefix + 'transform: rotateX(180deg);  }' +

                '}');

            // Fold (first item)
            utils.inject( '@' + prefix + 'keyframes fold-first    {' +

                '0%   {' + prefix + 'transform: rotateX(0deg);    }' +
                '100% {' + prefix + 'transform: rotateX(-180deg); }' +

                '}');

            // Swing out
            utils.inject( '@' + prefix + 'keyframes swing-out     {' +

                '0%   {' + prefix + 'transform: rotateX(0deg);    }' +
                '30%  {' + prefix + 'transform: rotateX(-30deg);  }' +
                '60%  {' + prefix + 'transform: rotateX(15deg);   }' +
                '100% {' + prefix + 'transform: rotateX(0deg);    }' +

                '}');

            // Swing in
            utils.inject( '@' + prefix + 'keyframes swing-in      {' +

                '0%   {' + prefix + 'transform: rotateX(0deg);    }' +
                '50%  {' + prefix + 'transform: rotateX(-10deg);  }' +
                '90%  {' + prefix + 'transform: rotateX(15deg);   }' +
                '100% {' + prefix + 'transform: rotateX(0deg);    }' +

                '}');

            // Shading (unfold)
            utils.inject( '@' + prefix + 'keyframes unfold-over   {' +
                '0%   { opacity: 1.0; }' +
                '100% { opacity: 0.0; }' +
                '}');

            // Shading (fold)
            utils.inject( '@' + prefix + 'keyframes fold-over     {' +
                '0%   { opacity: 0.0; }' +
                '100% { opacity: 1.0; }' +
                '}');

            // Node styles
            utils.inject( '.node {' +
                'position: absolute;' +
                'display: block;' +
                '}');

            // Face styles
            utils.inject( '.face {' +
                'pointer-events: none;' +
                'position: absolute;' +
                'display: block;' +
                'height: 100%;' +
                'width: 100%;' +
                'left: 0;' +
                'top: 0;' +
                '}');
        }

        // Merge options & defaults
        var opts = jQuery.extend( {}, jQuery.fn.makisu.defaults, options );

        // Extract api method arguments
        var args = Array.prototype.slice.call( arguments, 1 );

        // Main plugin loop
        return this.each( function () {

            // If the user is calling a method...
            if ( api[ options ] ) {
                return api[ options ].apply( this, args );
            }

            // Store options in view
            jQuerythis = jQuery( this ).data( opts );

            // Only proceed if the scene hierarchy isn't already built
            if ( !jQuerythis.data( 'initialized' ) ) {

                jQuerythis.data( 'initialized', true );

                // Select the first level of matching child elements
                jQuerykids = jQuery('#rollMenu > .list').children( "li" );

                // Build a scene graph for elements
                jQueryroot = jQuery( markup.node ).addClass( 'root' );
                jQuerybase = jQueryroot;
                
                // Process each element and insert into hierarchy
                jQuerykids.each( function( index, el ) {

                    jQueryitem = jQuery( el );

                    // Which animation should this node use?
                    anim = 'fold' + ( !index ? '-first' : '' );

                    // Since we're adding absolutely positioned children
                    jQueryitem.css( 'position', 'relative' );

                    // Give the item some depth to avoid clipping artefacts
                    jQueryitem.css(utils.prefix({
                        'transform-style': 'preserve-3d',
                        'transform': 'translateZ(-0.1px)'
                    }));

                    // Create back face
                    jQueryback = jQuery( markup.back );
                    jQueryback.css( 'background', jQueryitem.css( 'background' ) );
                    jQueryback.css(utils.prefix({ 'transform': 'translateZ(-0.1px)' }));

                    // Create shading
                    jQueryover = jQuery( markup.over );
                    jQueryover.css(utils.prefix({ 'transform': 'translateZ(0.1px)' }));
                    jQueryover.css({
                        'background': opts.shading,
                        'opacity': 0.0
                    });
                    
                    // Begin folded
                    jQuerynode = jQuery( markup.node ).append( jQueryitem );
                    jQuerynode.css(utils.prefix({
                        'transform-origin': '50% 0%',
                        'transform-style': 'preserve-3d',
                        'animation': anim + ' 1ms linear 0s 1 normal forwards'
                    }));

                    // Build display list
                    jQueryitem.append( jQueryover );
                    jQueryitem.append( jQueryback );
                    jQuerybase.append( jQuerynode );

                    // Use as parent in next iteration
                    jQuerybase = jQuerynode;
                });

                // Set root transform settings
                jQueryroot.css(utils.prefix({
                    'transform-origin': '50% 0%',
                    'transform-style': 'preserve-3d'
                }));

                // Apply perspective
                jQuerythis.css(utils.prefix({
                    'transform': 'perspective(' + opts.perspective + 'px)'
                }));

                // Display the scene
                jQuerythis.append( jQueryroot );
            }
        });
    };

    // Default options
    jQuery.fn.makisu.defaults = {

        // Perspective to apply to rotating elements
        perspective: 1200,

        // Default shading to apply (null => no shading)
        shading: 'rgba(0,0,0,0.12)',

        // Area of rotation (fraction or pixel value)
        selector: null,

        // Fraction of speed (0-1)
        overlap: 0.6,

        // Duration per element
        speed: 0.8,

        // Animation curve
        easing: 'ease-in-out'
    };

    jQuery.fn.makisu.enabled = canRun;

})( jQuery );

// The `enabled` flag will be `false` if CSS 3D isn't available

if ( jQuery.fn.makisu.enabled ) {

    var jQuerysashimi = jQuery( '.sashimi' );
    var jQuerynigiri = jQuery( '.tilt' );
    var jQuerymaki = jQuery( '.noTilt' );

    // Create Makisus

    jQuerynigiri.makisu({
        selector: 'li',
        overlap: 0.85,
        speed: 1.3
    });

    jQuerymaki.makisu({
        selector: 'li',
        overlap: 0.6,
        speed: 0.85
    });

    jQuerysashimi.makisu({
        selector: 'li',
        overlap: 0.2,
        speed: 0.5
    });

    // Open all
    
    // jQuery( '.list' ).makisu( 'open' ); 

    // Toggle on click

    jQuery( '.toggle' ).on( 'click', function() {
        jQuery( '.list' ).makisu( 'toggle' );
    });

    // Disable all links

    // jQuery( '.rollMenu a' ).click( function( event ) {
        // event.preventDefault();
    // });

} else {

    // jQuery( '.warning' ).show();
}
//Toggle
	jQuery("#listTitle").click(function () {
		  if (jQuery('#rollMenu ul').hasClass('open')) {
		  	  jQuery('#listTitle span').hide('fast').text('-').show('fast');
		  	//var liCount = jQuery("#rollMenu > ul li").length;
		  	//var liCount = jQuery('#rollMenu ul').children().length;
		  	var liCount = jQuery("#rollMenu > ul li").not("#rollMenu ul ul li").length;
		  	liCount2 = liCount * -36;
		  	//alert(liCount);
		      jQuery('.sidebar').css('margin-top', liCount2 + 'px');
		      jQuery('.node').css('position', 'relative');
		      jQuery('.sidebar').stop().animate({marginTop: '0px'}, 2000, function() {});
		  }
		  else{
		  	jQuery('#listTitle span').hide('fast').text('+').show('fast');
		  	  var menuHeight = jQuery('#rollMenu').height();
		      jQuery('.node').css('position', 'absolute');
		      jQuery('.sidebar').css('margin-top', menuHeight-'55');
		      jQuery('.sidebar').stop().animate({marginTop: '0px'}, 2000, function() {});
		  	
		  }
	});
	
	}
	
});